%?mingw_package_header

# first two digits of version
%global release_version %(echo %{version} | awk -F. '{print $1"."$2}')

Name:           mingw-gtkhtml3
Version:        4.8.0
Release:        %mkrel 8
Summary:        MinGW library for embedding a lightweight web browser in GTK programs

License:        LGPLv2+
Group:          Development/Other
URL:            http://projects.gnome.org/evolution/
Source:         https://download.gnome.org/sources/gtkhtml/%{release_version}/gtkhtml-%{version}.tar.xz

# The configure script searches for the presence of the pkgconfig file for
# gnome-icon-theme which we don't have for Fedora-MinGW (as it only contains
# a collection of icons and no source code). This patch strips out the
# dependency for gnome-icon-theme and shouldn't cause any side-effects
Patch1:         gtkhtml-dont-search-for-gnome-icon-theme.patch

# The same situation as with Patch1 also applies to the iso-codes dependency 
Patch2:         gtkhtml-make-iso-codes-optional.patch

# Strip out the gsettings-desktop-schemas dependency
Patch3:         gtkhtml-make-gsettings-desktop-schemas-optional.patch

# Normally GtkHTML always exports a function named 'DllMain' on
# Win32 environments. When GtkHTML is built as a static library, this
# function doesn't serve any purpose and it can introduce potential
# conflicts with other static libraries which may export a 'DllMain' function
# This patch causes the DllMain function to be ignore when GtkHTML is
# being built as a static library
Patch4:         gtkhtml_enable_static_build.patch

BuildArch:      noarch

BuildRequires:  mingw32-filesystem >= 95
BuildRequires:  mingw32-gcc
BuildRequires:  mingw32-binutils
BuildRequires:  mingw32-gtk3
BuildRequires:  mingw32-libgnurx
BuildRequires:  mingw32-libsoup
BuildRequires:  mingw32-enchant

BuildRequires:  mingw64-filesystem >= 95
BuildRequires:  mingw64-gcc
BuildRequires:  mingw64-binutils
BuildRequires:  mingw64-gtk3
BuildRequires:  mingw64-libgnurx
BuildRequires:  mingw64-libsoup
BuildRequires:  mingw64-enchant

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  intltool
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  gettext-devel


%description
GtkHTML is a lightweight HTML rendering/printing/editing engine
This is the MinGW build of GtkHTML


# Win32
%package -n mingw32-gtkhtml3
Summary:        MinGW library for embedding a lightweight web browser in GTK programs
Requires:       pkgconfig

%description -n mingw32-gtkhtml3
GtkHTML is a lightweight HTML rendering/printing/editing engine
This is the MinGW build of GtkHTML

%package -n mingw32-gtkhtml3-static
Summary:        Static version of the MinGW Windows GtkHTML library
Requires:       mingw32-gtkhtml3 = %{version}-%{release}
Group:          Development/Other

%description -n mingw32-gtkhtml3-static
Static version of the MinGW Windows GtkHTML library.

# Win64
%package -n mingw64-gtkhtml3
Summary:        MinGW library for embedding a lightweight web browser in GTK programs
Requires:       pkgconfig

%description -n mingw64-gtkhtml3
GtkHTML is a lightweight HTML rendering/printing/editing engine
This is the MinGW build of GtkHTML

%package -n mingw64-gtkhtml3-static
Summary:        Static version of the MinGW Windows GtkHTML library
Requires:       mingw64-gtkhtml3 = %{version}-%{release}
Group:          Development/Other

%description -n mingw64-gtkhtml3-static
Static version of the MinGW Windows GtkHTML library.


%?mingw_debug_package


%prep
%setup -q -n gtkhtml-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p0

libtoolize --copy --force
autoreconf --install --force


%build
# GtkHTML can't build static and shared libraries in one go, so we
# build GtkHTML twice here
export CFLAGS="$CFLAGS -DGLIB_STATIC_COMPILATION -DGOBJECT_STATIC_COMPILATION"
MINGW_BUILDDIR_SUFFIX=_static %mingw_configure --disable-deprecated-warning-flags --enable-static --disable-shared
unset CFLAGS
MINGW_BUILDDIR_SUFFIX=_shared %mingw_configure --disable-deprecated-warning-flags --disable-static --enable-shared

MINGW_BUILDDIR_SUFFIX=_static %mingw_make %{?_smp_mflags}
MINGW_BUILDDIR_SUFFIX=_shared %mingw_make %{?_smp_mflags}


%install
# First install all the files belonging to the shared build
MINGW_BUILDDIR_SUFFIX=_shared %mingw_make DESTDIR=$RPM_BUILD_ROOT install

# Install all the files from the static build in a seperate folder
# and move the static libraries to the right location
MINGW_BUILDDIR_SUFFIX=_static %mingw_make DESTDIR=$RPM_BUILD_ROOT/build_static install
mv $RPM_BUILD_ROOT/build_static%{mingw32_libdir}/*.a $RPM_BUILD_ROOT%{mingw32_libdir}
mv $RPM_BUILD_ROOT/build_static%{mingw64_libdir}/*.a $RPM_BUILD_ROOT%{mingw64_libdir}

# Drop the folder which was temporary used for installing the static bits
rm -rf $RPM_BUILD_ROOT/build_static

# Drop all .la files
find $RPM_BUILD_ROOT -name "*.la" -delete

# Install a small test program
install -m0755 build_win32_shared/gtkhtml/.libs/testgtkhtml.exe $RPM_BUILD_ROOT%{mingw32_bindir}/testgtkhtml.exe
install -m0755 build_win64_shared/gtkhtml/.libs/testgtkhtml.exe $RPM_BUILD_ROOT%{mingw64_bindir}/testgtkhtml.exe

%mingw_find_lang gtkhtml-4.0


# Win32
%files -n mingw32-gtkhtml3 -f mingw32-gtkhtml-4.0.lang
%doc COPYING.LIB
%{mingw32_bindir}/gtkhtml-editor-test.exe
%{mingw32_bindir}/libgtkhtml-4.0-0.dll
%{mingw32_bindir}/libgtkhtml-editor-4.0-0.dll
%{mingw32_bindir}/testgtkhtml.exe
%{mingw32_includedir}/libgtkhtml-4.0
%{mingw32_libdir}/libgtkhtml-4.0.dll.a
%{mingw32_libdir}/libgtkhtml-editor-4.0.dll.a
%{mingw32_libdir}/pkgconfig/libgtkhtml-4.0.pc
%{mingw32_libdir}/pkgconfig/gtkhtml-editor-4.0.pc
%{mingw32_datadir}/gtkhtml-4.0

%files -n mingw32-gtkhtml3-static
%{mingw32_libdir}/libgtkhtml-4.0.a
%{mingw32_libdir}/libgtkhtml-editor-4.0.a

# Win64
%files -n mingw64-gtkhtml3 -f mingw64-gtkhtml-4.0.lang
%doc COPYING.LIB
%{mingw64_bindir}/gtkhtml-editor-test.exe
%{mingw64_bindir}/libgtkhtml-4.0-0.dll
%{mingw64_bindir}/libgtkhtml-editor-4.0-0.dll
%{mingw64_bindir}/testgtkhtml.exe
%{mingw64_includedir}/libgtkhtml-4.0
%{mingw64_libdir}/libgtkhtml-4.0.dll.a
%{mingw64_libdir}/libgtkhtml-editor-4.0.dll.a
%{mingw64_libdir}/pkgconfig/libgtkhtml-4.0.pc
%{mingw64_libdir}/pkgconfig/gtkhtml-editor-4.0.pc
%{mingw64_datadir}/gtkhtml-4.0

%files -n mingw64-gtkhtml3-static
%{mingw64_libdir}/libgtkhtml-4.0.a
%{mingw64_libdir}/libgtkhtml-editor-4.0.a




%changelog
* Thu Mar 31 2022 umeabot <umeabot> 4.8.0-8.mga9
+ Revision: 1836151
- Mageia 9 Mass Rebuild

* Sat Sep 26 2020 tv <tv> 4.8.0-7.mga8
+ Revision: 1630513
- rebuild for new mingw stack

* Wed Feb 12 2020 umeabot <umeabot> 4.8.0-6.mga8
+ Revision: 1492083
- Mageia 8 Mass Rebuild

* Wed Sep 19 2018 umeabot <umeabot> 4.8.0-5.mga7
+ Revision: 1264284
- Mageia 7 Mass Rebuild

* Mon Feb 08 2016 umeabot <umeabot> 4.8.0-4.mga6
+ Revision: 943152
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 4.8.0-3.mga5
+ Revision: 746457
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 4.8.0-2.mga5
+ Revision: 682453
- Mageia 5 Mass Rebuild

* Mon Mar 24 2014 ovitters <ovitters> 4.8.0-1.mga5
+ Revision: 607869
- new version 4.8.0

* Mon Oct 28 2013 neoclust <neoclust> 4.6.6-1.mga4
+ Revision: 547631
- imported package mingw-gtkhtml3


* Sat Sep  7 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 4.6.6-1
- Update to 4.6.6

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.6.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sun Jun 16 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 4.6.5-2
- Rebuild to resolve InterlockedCompareExchange regression in mingw32 libraries

* Sat Jun 15 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 4.6.5-1
- Update to 4.6.5

* Sun Mar 24 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 4.6.4-1
- Update to 4.6.4

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.4.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.4.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sun Apr  8 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 4.4.0-1
- Update to 4.4.0
- Added win64 support
- Link against gtk3
- Dropped upstreamed GConf patch
- Dropped upstreamed g_thread_init patch

* Fri Mar 09 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.32.2-7
- Don't use g_thread_init anymore

* Tue Mar 06 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.32.2-6
- Renamed the source package to mingw-gtkhtml3 (RHBZ #800393)
- Use mingw macros without leading underscore

* Tue Feb 28 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.32.2-5
- Rebuild against the mingw-w64 toolchain

* Tue Jan 31 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.32-2-4
- Rebuild against libpng 1.5
- Dropped unneeded RPM tags
- Dropped the dependency extraction overrides as that's done automatically as of RPM 4.9
- Dropped all .la files

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.32.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Thu Jul  7 2011 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.32.2-2
- Rebuild against win-iconv

* Wed Apr 27 2011 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.32.2-1
- Update to 3.32.2
- Dropped the proxy-libintl pieces

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.32.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Nov  8 2010 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.32.0-2
- Rebuild in order to have soft dependency on libintl

* Mon Oct 11 2010 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.32.0-1
- Update to 3.32.0
- Build with the configure argument --disable-deprecated-warning-flags
  for now due to upstream breakage (GNOME BZ #630875)

* Fri Sep 24 2010 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.31.92-1
- Update to 3.31.92

* Tue Jul  6 2010 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.30.2-1
- Update to 3.30.2

* Fri Jun 11 2010 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.30.1-1
- Update to 3.30.1 (Fixes RHBZ #599778 and #564909)

* Fri Dec 11 2009 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.29.3-2
- Looks like the original license tag was correct: LGPLv2+
- Bundle COPYING.LIB instead of COPYING

* Fri Dec 11 2009 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.29.3-1
- Update to 3.29.3
- Renamed 'webbrowser' in the summary to 'web browser' to keep rpmlint happy
- Fixed the license tag

* Thu Sep 24 2009 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.28.0-1
- Update to 3.28.0
- Use %%global instead of %%define
- Automatically generate debuginfo subpackage
- Simplified the original patch to strip unnecessary deps
- Added translations

* Fri Apr  3 2009 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.25.90-2
- Added -static subpackage

* Fri Feb 13 2009 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.25.90-1
- Initial release

